attach

Function attach 

fn attach(socket: &Socket, prog: &mut [sock_filter]) -> Result<()>
Attach a cBPF program to a socket via SO_ATTACH_FILTER. The kernel copies the program during the call, so prog need only remain valid for the duration of this function.